# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .access_token import *
from .agent_pool import *
from .deployment_schedule import *
from .deployment_settings import *
from .drift_schedule import *
from .environment import *
from .org_access_token import *
from .provider import *
from .stack_tag import *
from .team import *
from .team_access_token import *
from .team_environment_permission import *
from .team_stack_permission import *
from .ttl_schedule import *
from .webhook import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_pulumiservice.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_pulumiservice.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "pulumiservice",
  "mod": "index",
  "fqn": "pulumi_pulumiservice",
  "classes": {
   "pulumiservice:index:AccessToken": "AccessToken",
   "pulumiservice:index:AgentPool": "AgentPool",
   "pulumiservice:index:DeploymentSchedule": "DeploymentSchedule",
   "pulumiservice:index:DeploymentSettings": "DeploymentSettings",
   "pulumiservice:index:DriftSchedule": "DriftSchedule",
   "pulumiservice:index:Environment": "Environment",
   "pulumiservice:index:OrgAccessToken": "OrgAccessToken",
   "pulumiservice:index:StackTag": "StackTag",
   "pulumiservice:index:Team": "Team",
   "pulumiservice:index:TeamAccessToken": "TeamAccessToken",
   "pulumiservice:index:TeamEnvironmentPermission": "TeamEnvironmentPermission",
   "pulumiservice:index:TeamStackPermission": "TeamStackPermission",
   "pulumiservice:index:TtlSchedule": "TtlSchedule",
   "pulumiservice:index:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "pulumiservice",
  "token": "pulumi:providers:pulumiservice",
  "fqn": "pulumi_pulumiservice",
  "class": "Provider"
 }
]
"""
)
